==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TreemapDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodeStylingEventArgsDescriptionMetadata } from "./TreemapNodeStylingEventArgsDescriptionMetadata";
import { TreemapNodePointerEventArgsDescriptionMetadata } from "./TreemapNodePointerEventArgsDescriptionMetadata";
import { TreemapDescription } from "./TreemapDescription";
/**
 * @hidden
 */
var TreemapDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapDescriptionMetadata, _super);
    function TreemapDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapDescriptionMetadata.b = function (a) {
        if (TreemapDescriptionMetadata.a == null) {
            TreemapDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapDescriptionMetadata.c(TreemapDescriptionMetadata.a);
        }
        if (a.g(TreemapDescriptionMetadata.a)) {
            return;
        }
        a.s(TreemapDescriptionMetadata.a);
        TreemapNodeStylingEventArgsDescriptionMetadata.d(a);
        TreemapNodePointerEventArgsDescriptionMetadata.d(a);
    };
    TreemapDescriptionMetadata.c = function (a) {
        a.item("ValueMemberPath", "String");
        a.item("RootTitle", "String");
        a.item("BreadcrumbSequence", "String");
        a.item("ParentIdMemberPath", "String");
        a.item("LabelMemberPath", "String");
        a.item("CustomValueMemberPath", "String");
        a.item("IdMemberPath", "String");
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,j:dataSource,wf:ItemsSource)DataRef::object");
        a.item("FillBrushes", "BrushCollection:string");
        a.item("StyleMappings", "Collection:TreemapNodeStyleMapping:TreemapNodeStyleMappingCollection:TreemapNodeStyleMapping");
        a.item("FillScaleMode", "ExportedType:string:TreemapFillScaleMode");
        a.item("FillScaleMode@names", "Sum;GlobalSum;Value;GlobalValue");
        a.item("IsFillScaleLogarithmic", "Boolean");
        a.item("FillScaleLogarithmBase", "Number:int");
        a.item("FillScaleMinimumValue", "Number:double");
        a.item("FillScaleMaximumValue", "Number:double");
        a.item("LabelVerticalFitMode", "ExportedType:string:TreemapLabelVerticalFitMode");
        a.item("LabelVerticalFitMode@names", "Auto;Show;Hide");
        a.item("LabelHorizontalFitMode", "ExportedType:string:TreemapLabelHorizontalFitMode");
        a.item("LabelHorizontalFitMode@names", "Auto;Ellipsis;Hide");
        a.item("OverlayHeaderHoverBackground", "Brush");
        a.item("HeaderHoverBackground", "Brush");
        a.item("HeaderBackground", "Brush");
        a.item("OverlayHeaderBackground", "Brush");
        a.item("HeaderTextColor", "Brush");
        a.item("HeaderDarkTextColor", "Brush");
        a.item("TextColor", "Brush");
        a.item("DarkTextColor", "Brush");
        a.item("HeaderHoverTextColor", "Brush");
        a.item("HeaderHoverDarkTextColor", "Brush");
        a.item("FontFamily", "(w:FontFamily/FontFamilyTransform,xam:FontFamily,wf:FontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("FontSize", "(w:FontSize,xam:FontSize,wf:FontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("FontStyle", "(w:FontStyle/FontStyleTransform,xam:FontFamily/FontStyleTransform,wf:FontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("FontWeight", "(w:FontWeight/FontWeightTransform,xam:FontFamily/FontWeightTransform,wf:FontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("HeaderFontFamily", "(w:HeaderFontFamily/FontFamilyTransform,xam:HeaderFontFamily,wf:HeaderFontFamily,web:headerTextStyle/FontFamilyTransform)String");
        a.item("HeaderFontSize", "(w:HeaderFontSize,xam:HeaderFontSize,wf:HeaderFontSize,web:headerTextStyle/FontSizeTransform)Number:double");
        a.item("HeaderFontStyle", "(w:HeaderFontStyle/FontStyleTransform,xam:HeaderFontFamily/FontStyleTransform,wf:HeaderFontFamily/FontStyleTransform,web:headerTextStyle/FontStyleTransform)String");
        a.item("HeaderFontWeight", "(w:HeaderFontWeight/FontWeightTransform,xam:HeaderFontFamily/FontWeightTransform,wf:HeaderFontFamily/FontWeightTransform,web:headerTextStyle/FontWeightTransform)String");
        a.item("HeaderDisplayMode", "ExportedType:string:TreemapHeaderDisplayMode");
        a.item("HeaderDisplayMode@names", "Auto;Header;Overlay");
        a.item("HeaderLabelLeftMargin", "Number:double");
        a.item("HeaderLabelTopMargin", "Number:double");
        a.item("HeaderLabelRightMargin", "Number:double");
        a.item("HeaderLabelBottomMargin", "Number:double");
        a.item("OverlayHeaderLabelLeftMargin", "Number:double");
        a.item("OverlayHeaderLabelTopMargin", "Number:double");
        a.item("OverlayHeaderLabelRightMargin", "Number:double");
        a.item("OverlayHeaderLabelBottomMargin", "Number:double");
        a.item("LabelLeftMargin", "Number:double");
        a.item("LabelTopMargin", "Number:double");
        a.item("LabelRightMargin", "Number:double");
        a.item("LabelBottomMargin", "Number:double");
        a.item("ParentNodeLeftMargin", "Number:double");
        a.item("ParentNodeTopMargin", "Number:double");
        a.item("ParentNodeRightMargin", "Number:double");
        a.item("ParentNodeBottomMargin", "Number:double");
        a.item("ParentNodeLeftPadding", "Number:double");
        a.item("ParentNodeTopPadding", "Number:double");
        a.item("ParentNodeRightPadding", "Number:double");
        a.item("ParentNodeBottomPadding", "Number:double");
        a.item("LabelHorizontalAlignment", "ExportedType:string:HorizontalAlignment");
        a.item("LabelHorizontalAlignment@names", "Left;Center;Right;Stretch");
        a.item("LabelVerticalAlignment", "ExportedType:string:VerticalAlignment");
        a.item("LabelVerticalAlignment@names", "Top;Center;Bottom;Stretch");
        a.item("HeaderHeight", "Number:double");
        a.item("Outline", "Brush");
        a.item("StrokeThickness", "Number:double");
        a.item("LayoutOrientation", "ExportedType:string:TreemapOrientation");
        a.item("LayoutOrientation@names", "Horizontal;Vertical");
        a.item("LayoutType", "ExportedType:string:TreemapLayoutType");
        a.item("LayoutType@names", "Squarified;SliceAndDice;Stripped");
        a.item("MinimumDisplaySize", "Number:double");
        a.item("TransitionDuration", "Number:int");
        a.item("PixelScalingRatio", "Number:double");
        a.item("ActualPixelScalingRatio", "Number:double");
        a.item("InteractionPixelScalingRatio", "Number:double");
        a.item("ActualInteractionPixelScalingRatio", "Number:double");
        a.item("FocusItemRef", "(w:FocusItem,wf:FocusItem)DataRef");
        a.item("NodeStylingRef", "EventRef::nodeStyling");
        a.item("NodePointerOverRef", "EventRef::nodePointerOver");
        a.item("NodePointerEnterRef", "EventRef::nodePointerEnter");
        a.item("NodePointerLeaveRef", "EventRef::nodePointerLeave");
        a.item("NodePointerPressedRef", "EventRef::nodePointerPressed");
        a.item("NodePointerReleasedRef", "EventRef::nodePointerReleased");
        TreemapDescriptionMetadata.e(a);
    };
    TreemapDescriptionMetadata.d = function (a) {
        TreemapDescriptionMetadata.b(a);
        a.u("Treemap", function () { return new TreemapDescription(); });
        a.t("Treemap", TreemapDescriptionMetadata.a);
    };
    TreemapDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamTreemap");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    TreemapDescriptionMetadata.$t = markType(TreemapDescriptionMetadata, 'TreemapDescriptionMetadata');
    TreemapDescriptionMetadata.a = null;
    return TreemapDescriptionMetadata;
}(Base));
export { TreemapDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TreemapDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodeStylingEventArgsDescriptionMetadata } from "./TreemapNodeStylingEventArgsDescriptionMetadata";
import { TreemapNodePointerEventArgsDescriptionMetadata } from "./TreemapNodePointerEventArgsDescriptionMetadata";
import { TreemapDescription } from "./TreemapDescription";
/**
 * @hidden
 */
var TreemapDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreemapDescriptionMetadata, _super);
    function TreemapDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapDescriptionMetadata.b = function (a) {
        if (TreemapDescriptionMetadata.a == null) {
            TreemapDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapDescriptionMetadata.c(TreemapDescriptionMetadata.a);
        }
        if (a.j(TreemapDescriptionMetadata.a)) {
            return;
        }
        a.y(TreemapDescriptionMetadata.a);
        TreemapNodeStylingEventArgsDescriptionMetadata.d(a);
        TreemapNodePointerEventArgsDescriptionMetadata.d(a);
    };
    TreemapDescriptionMetadata.c = function (a) {
        a.item("ValueMemberPath", "String");
        a.item("RootTitle", "String");
        a.item("BreadcrumbSequence", "String");
        a.item("ParentIdMemberPath", "String");
        a.item("LabelMemberPath", "String");
        a.item("CustomValueMemberPath", "String");
        a.item("IdMemberPath", "String");
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,j:dataSource,wf:ItemsSource)DataRef::object");
        a.item("FillBrushes", "BrushCollection:string");
        a.item("StyleMappings", "Collection:TreemapNodeStyleMapping:TreemapNodeStyleMappingCollection:TreemapNodeStyleMapping");
        a.item("FillScaleMode", "ExportedType:string:TreemapFillScaleMode");
        a.item("FillScaleMode@names", "Sum;GlobalSum;Value;GlobalValue");
        a.item("IsFillScaleLogarithmic", "Boolean");
        a.item("FillScaleLogarithmBase", "Number:int");
        a.item("FillScaleMinimumValue", "Number:double");
        a.item("FillScaleMaximumValue", "Number:double");
        a.item("LabelVerticalFitMode", "ExportedType:string:TreemapLabelVerticalFitMode");
        a.item("LabelVerticalFitMode@names", "Auto;Show;Hide");
        a.item("LabelHorizontalFitMode", "ExportedType:string:TreemapLabelHorizontalFitMode");
        a.item("LabelHorizontalFitMode@names", "Auto;Ellipsis;Hide");
        a.item("OverlayHeaderHoverBackground", "Brush");
        a.item("HeaderHoverBackground", "Brush");
        a.item("HeaderBackground", "Brush");
        a.item("OverlayHeaderBackground", "Brush");
        a.item("HeaderTextColor", "Brush");
        a.item("HeaderDarkTextColor", "Brush");
        a.item("TextColor", "Brush");
        a.item("DarkTextColor", "Brush");
        a.item("HeaderHoverTextColor", "Brush");
        a.item("HeaderHoverDarkTextColor", "Brush");
        a.item("FontFamily", "(w:FontFamily/FontFamilyTransform,xam:FontFamily,wf:FontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("FontSize", "(w:FontSize,xam:FontSize,wf:FontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("FontStyle", "(w:FontStyle/FontStyleTransform,xam:FontFamily/FontStyleTransform,wf:FontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("FontWeight", "(w:FontWeight/FontWeightTransform,xam:FontFamily/FontWeightTransform,wf:FontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("HeaderFontFamily", "(w:HeaderFontFamily/FontFamilyTransform,xam:HeaderFontFamily,wf:HeaderFontFamily,web:headerTextStyle/FontFamilyTransform)String");
        a.item("HeaderFontSize", "(w:HeaderFontSize,xam:HeaderFontSize,wf:HeaderFontSize,web:headerTextStyle/FontSizeTransform)Number:double");
        a.item("HeaderFontStyle", "(w:HeaderFontStyle/FontStyleTransform,xam:HeaderFontFamily/FontStyleTransform,wf:HeaderFontFamily/FontStyleTransform,web:headerTextStyle/FontStyleTransform)String");
        a.item("HeaderFontWeight", "(w:HeaderFontWeight/FontWeightTransform,xam:HeaderFontFamily/FontWeightTransform,wf:HeaderFontFamily/FontWeightTransform,web:headerTextStyle/FontWeightTransform)String");
        a.item("HeaderDisplayMode", "ExportedType:string:TreemapHeaderDisplayMode");
        a.item("HeaderDisplayMode@names", "Auto;Header;Overlay");
        a.item("HeaderLabelLeftMargin", "Number:double");
        a.item("HeaderLabelTopMargin", "Number:double");
        a.item("HeaderLabelRightMargin", "Number:double");
        a.item("HeaderLabelBottomMargin", "Number:double");
        a.item("OverlayHeaderLabelLeftMargin", "Number:double");
        a.item("OverlayHeaderLabelTopMargin", "Number:double");
        a.item("OverlayHeaderLabelRightMargin", "Number:double");
        a.item("OverlayHeaderLabelBottomMargin", "Number:double");
        a.item("LabelLeftMargin", "Number:double");
        a.item("LabelTopMargin", "Number:double");
        a.item("LabelRightMargin", "Number:double");
        a.item("LabelBottomMargin", "Number:double");
        a.item("ParentNodeLeftMargin", "Number:double");
        a.item("ParentNodeTopMargin", "Number:double");
        a.item("ParentNodeRightMargin", "Number:double");
        a.item("ParentNodeBottomMargin", "Number:double");
        a.item("ParentNodeLeftPadding", "Number:double");
        a.item("ParentNodeTopPadding", "Number:double");
        a.item("ParentNodeRightPadding", "Number:double");
        a.item("ParentNodeBottomPadding", "Number:double");
        a.item("LabelHorizontalAlignment", "ExportedType:string:HorizontalAlignment");
        a.item("LabelHorizontalAlignment@names", "Left;Center;Right;Stretch");
        a.item("LabelVerticalAlignment", "ExportedType:string:VerticalAlignment");
        a.item("LabelVerticalAlignment@names", "Top;Center;Bottom;Stretch");
        a.item("HeaderHeight", "Number:double");
        a.item("Outline", "Brush");
        a.item("StrokeThickness", "Number:double");
        a.item("LayoutOrientation", "ExportedType:string:TreemapOrientation");
        a.item("LayoutOrientation@names", "Horizontal;Vertical");
        a.item("LayoutType", "ExportedType:string:TreemapLayoutType");
        a.item("LayoutType@names", "Squarified;SliceAndDice;Stripped");
        a.item("MinimumDisplaySize", "Number:double");
        a.item("TransitionDuration", "Number:int");
        a.item("PixelScalingRatio", "Number:double");
        a.item("ActualPixelScalingRatio", "Number:double");
        a.item("InteractionPixelScalingRatio", "Number:double");
        a.item("ActualInteractionPixelScalingRatio", "Number:double");
        a.item("FocusItemRef", "(w:FocusItem,wf:FocusItem)DataRef");
        a.item("NodeStylingRef", "EventRef::nodeStyling");
        a.item("NodePointerOverRef", "EventRef::nodePointerOver");
        a.item("NodePointerEnterRef", "EventRef::nodePointerEnter");
        a.item("NodePointerLeaveRef", "EventRef::nodePointerLeave");
        a.item("NodePointerPressedRef", "EventRef::nodePointerPressed");
        a.item("NodePointerReleasedRef", "EventRef::nodePointerReleased");
        TreemapDescriptionMetadata.e(a);
    };
    TreemapDescriptionMetadata.d = function (a) {
        TreemapDescriptionMetadata.b(a);
        a.aa("Treemap", function () { return new TreemapDescription(); });
        a.z("Treemap", TreemapDescriptionMetadata.a);
    };
    TreemapDescriptionMetadata.e = function (a) {
        a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamTreemap");
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    TreemapDescriptionMetadata.$t = markType(TreemapDescriptionMetadata, 'TreemapDescriptionMetadata');
    TreemapDescriptionMetadata.a = null;
    return TreemapDescriptionMetadata;
}(Base));
export { TreemapDescriptionMetadata };
